@@ -149,6 +149,7 @@ if assume_done is not None:
 
 
 def try_hidden_desktop(cmd_line, cwd=None, disp_str=""):
+    # TODO: Move this out as it doesn't require Stata (sub print_during_build)
     try:
         import win32con
         import pywintypes
@@ -442,7 +443,7 @@ def get_datasign(fname):
     return sig
 
 
-def init_env(env: Environment = None, patch_scons_sig_fns: bool = True,
+def init_env(env: Environment = None, tools: list = [], patch_scons_sig_fns: bool = True,
              skip_scons_vs_check: bool = False) -> Environment:
     """Sets up an environment for Stata.
 
@@ -465,6 +466,8 @@ def init_env(env: Environment = None, patch_scons_sig_fns: bool = True,
         Environment to configure for Stata support. If not provided will instantiate a DefaultEnvironment with the
         `os.environ` and no tools (many Stata users don't have defaults ones that SCons would complain about not
         finding).
+    tools :
+        List of tools to initialize the returned environment with.
     patch_scons_sig_fns :
         Whether to patch the SCons file signature functions to support special signature functions by file extensions.
         Default support is provided for .dta files.
@@ -478,7 +481,7 @@ def init_env(env: Environment = None, patch_scons_sig_fns: bool = True,
               + " and statacons has only been tested on 4.2.0+.")
 
     if env is None:
-        env = DefaultEnvironment(ENV=os.environ, tools=[])
+        env = DefaultEnvironment(ENV=os.environ, tools=tools)
     global int_env
     int_env = env
 
@@ -532,17 +535,20 @@ def init_env(env: Environment = None, patch_scons_sig_fns: bool = True,
             if not GetOption('silent'):
                 if m_str != "DataOnly" and m_str != "Datasignature" and m_str != "LabelsFormatsOnly":
                     print("Using 'Strict' custom_datasignature.")
-                    print("Calculates timestamp-independent checksum of dataset, including all metadata.")
+                    print("Calculates timestamp-independent checksum of dataset, ")
+                    print("  including all metadata.")
                     print("Edit use_custom_datasignature in config_project.ini to change.")
                     print("  (other options are DataOnly, LabelsFormatsOnly, False)")
                 elif m_str == "LabelsFormatsOnly":
                     print("Using 'LabelsFormatsOnly' custom_datasignature.")
-                    print("Calculates timestamp-independent checksum of dataset, including variable and value labels.")
+                    print("Calculates timestamp-independent checksum of dataset, ")
+                    print("  including variable formats, variable labels and value labels.")
                     print("Edit use_custom_datasignature in config_project.ini to change.")
                     print("  (other options are Strict, DataOnly, False)")
                 else:
                     print("Using 'DataOnly' datasignature.")
-                    print("Calculates timestamp-independent checksum of dataset, not including metadata")
+                    print("Calculates timestamp-independent checksum of dataset,")
+                    print("  not including metadata.")
                     print("Edit use_custom_datasignature in config_project.ini to change.")
                     print("  (other options are Strict, LabelsFormatsOnly, False)")
         elif not GetOption('silent'):
